Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type URI ¶
URI implements a parser for a URI format based on the the PKCS #11 URI Scheme defined in https://tools.ietf.org/html/rfc7512
These URIs will be used to define the key names in a KMS.
func ParseWithScheme ¶
ParseWithScheme returns the URI for the given string only if it has the given scheme.
Click to show internal directories.
Click to hide internal directories.